@@ -17,9 +17,9 @@ import gzip
 import json
 
 
-if os.path.isfile("barrins_codex/library.json.gz"):
+if os.path.isfile("library.json.gz"):
     # File exists
-    cartes = json.load(gzip.open("barrins_codex/library.json.gz"))
+    cartes = json.load(gzip.open("library.json.gz"))
 else:
     # Build file
     from . import build_library
@@ -304,6 +304,9 @@ def display_deck():
             "types": info["types"],
         }
 
+    def _key(card):
+        return card["name"]
+
     def deck_from_moxfield(key: str) -> json:
         url = "https://api.moxfield.com/v2/decks/all/"
 
@@ -328,21 +331,6 @@ def display_deck():
 
                 if len(card["types"]) == 1:
                     land["cards"].append(card)
-                elif "Creature" in card["types"]:
-                    if "/" not in name:
-                        crea["count"] = crea["count"] + int(card["count"])
-                        land["cards"].append(card)
-                        continue  #: Will never add "Dryad Arbor" to Creatures
-                elif "Enchantment" in card["types"]:
-                    if "/" not in name:
-                        ench["count"] = ench["count"] + int(card["count"])
-                        land["cards"].append(card)
-                        continue  #: Will never add Urza's Saga to Enchantments
-                elif "Artifact" in card["types"]:
-                    if "/" not in name:
-                        arti["count"] = arti["count"] + int(card["count"])
-                        land["cards"].append(card)
-                        continue  #: Will never add Seat of the Synod to Artifacts
 
             if "Creature" in card["types"]:
                 crea["count"] = crea["count"] + int(card["count"])
@@ -374,6 +362,15 @@ def display_deck():
             card["count"] = v["quantity"]
             czon.append(card)
 
+        czon.sort(key=_key)
+        crea["cards"].sort(key=_key)
+        plan["cards"].sort(key=_key)
+        arti["cards"].sort(key=_key)
+        ench["cards"].sort(key=_key)
+        inst["cards"].sort(key=_key)
+        sorc["cards"].sort(key=_key)
+        land["cards"].sort(key=_key)
+
         return json.dumps(
             {
                 "name": deck_json["name"],
