@@ -128,11 +128,12 @@ STRUCTURE = Nav(
             ],
         ),
         Nav(
-            lazy_gettext("Tools"),
+            lazy_gettext("Outils"),
             index=True,
             children=[
                 Nav(lazy_gettext("Combo A + B")),
                 Nav(lazy_gettext("Ik-O-Maths")),
+                Nav(lazy_gettext("Modern Duel Commander")),
                 Nav(lazy_gettext("Tirage au sort")),
             ],
         ),
