@@ -1,8 +1,26 @@
 function cardElement (element) {
-	return `<li>${element.count} <span class="card" scryfallId="${element.id}" data-tippy-content="
+	line = `<li>${element.count} <span class="card" scryfallId="${element.id}" data-tippy-content="
 		<div class='card-container'>
 			<img data-src='https://api.scryfall.com/cards/${element.id}?format=image' class='card-image'>
-		</div>" >${element.name}</span></li>`
+		</div>" >${element.name}</span>`
+
+	// Banned cards
+	if (element.name == "Gifts Ungiven") {
+		line = line + ` <span title="banned on July 26th 2021"><i class="fas fa-exclamation-triangle fa-xs"></i></span>`
+	}
+
+	// MDFC Land Cards
+	if ((element.types.length > 1) && (element.types.includes("Land"))) {
+		if (
+			(element.name != "Dryad Arbor")
+			&& !(element.types.includes("Enchantment"))
+			&& !(element.types.includes("Artifact"))
+		) {
+			line = line + ` <i class="fas fa-globe-europe fa-xs"></i>`
+		}
+	}
+
+	return line + `</li>`
 }
 
 function wrapText (text, maxlen) {
